/*
  Xinvest/Xquote Copyright 1995-97 Mark Buser,
  All Rights Reserved.

  Permission is hereby granted to copy
  and freely distribute copies of this
  program for non-commercial purposes
  without fee, provided that this notice
  appears in all copies.
  
  All redistributions must be in their
  entirety as originally distributed.
  Feel free to modify Xinvest/Xquote, but
  modified versions may not be distributed
  without prior consent of the author.
  
  This software is provided 'as-is'
  without any express or implied warranty.
  In no event will the author be held
  liable for any damages resulting from
  the use of this software.

  $Revision: 2.2 $ $Date: 1997/12/07 22:17:04 $
*/

#ifndef status_h
#define status_h

#include <Xm/Xm.h>

/* levels for write_status */
#define WARN XmDIALOG_WARNING
#define ERR  XmDIALOG_ERROR
#define INFO XmDIALOG_INFORMATION
#define LOG  XmDIALOG_MESSAGE

extern char errmsg[256];
void write_status (char *info, int level);
#ifdef XQUOTE
void write_status_line (char *);
#endif

int bound_ok ( int, int, int *, int );
int suppressed ();
void suppress ( int );
#endif
